@@ -18,11 +18,12 @@
 
 /* The interfaces in this file are subject to change at any time. */
 
-#ident "$Id: debug.h,v 1.13 2002/11/25 20:39:19 nalin Exp $"
-
 #ifndef vte_debug_h_included
 #define vte_debug_h_included
 
+
+#include <glib.h>
+
 G_BEGIN_DECLS
 
 typedef enum {
@@ -37,7 +38,9 @@ typedef enum {
 	VTE_DEBUG_RING		= 1 << 8,
 	VTE_DEBUG_PTY		= 1 << 9,
 	VTE_DEBUG_CURSOR	= 1 << 10,
-	VTE_DEBUG_KEYBOARD	= 1 << 11
+	VTE_DEBUG_KEYBOARD	= 1 << 11,
+	VTE_DEBUG_LIFECYCLE	= 1 << 12,
+	VTE_DEBUG_TRIE		= 1 << 13
 } VteDebugFlags;
 
 void _vte_debug_parse_string(const char *string);
