@@ -16,7 +16,6 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: nativeecho.c,v 1.3 2003/05/01 20:50:53 nalin Exp $"
 #include "../config.h"
 #include <limits.h>
 #include <stdio.h>
@@ -24,7 +23,7 @@
 #include <string.h>
 #include <unistd.h>
 #include "table.h"
-#define ESC ""
+#define ESC "\033"
 
 int
 main(int argc, char **argv)
