@@ -16,9 +16,11 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: trie.c,v 1.36 2006/01/30 12:23:49 gpastore Exp $"
 #include "../config.h"
 #include <sys/types.h>
+#ifdef HAVE_SYS_SYSLIMITS_H
+#include <sys/syslimits.h>
+#endif
 #include <assert.h>
 #include <ctype.h>
 #include <stdio.h>
@@ -372,7 +374,7 @@ static struct char_class char_classes[] = {
 TRIE_MAYBE_STATIC struct _vte_trie *
 _vte_trie_new(void)
 {
-	return g_malloc0(sizeof(struct _vte_trie));
+	return g_slice_new0(struct _vte_trie);
 }
 
 TRIE_MAYBE_STATIC void
@@ -385,7 +387,7 @@ _vte_trie_free(struct _vte_trie *trie)
 	if (trie->trie_path_count > 0) {
 		g_free(trie->trie_paths);
 	}
-	g_free(trie);
+	g_slice_free(struct _vte_trie, trie);
 }
 
 /* Add the given pattern, with its own result string, to the trie, with the
@@ -517,7 +519,7 @@ _vte_trie_add(struct _vte_trie *trie, const char *pattern, size_t length,
 }
 
 /* Check if the given pattern matches part of the given trie, returning an
- * empty string on a partial initial match, a NULL if there's no match in the
+ * empty string on a partial initial match, a %NULL if there's no match in the
  * works, and the result string if we have an exact match. */
 static const char *
 _vte_trie_matchx(struct _vte_trie *trie, const gunichar *pattern, size_t length,
@@ -668,7 +670,7 @@ _vte_trie_matchx(struct _vte_trie *trie, const gunichar *pattern, size_t length,
 }
 
 /* Check if the given pattern matches part of the given trie, returning an
- * empty string on a partial initial match, a NULL if there's no match in the
+ * empty string on a partial initial match, a %NULL if there's no match in the
  * works, and the result string if we have an exact match. */
 TRIE_MAYBE_STATIC const char *
 _vte_trie_match(struct _vte_trie *trie, const gunichar *pattern, size_t length,
